Struct Awscdr
#[repr(transparent)]pub struct Awscdr(pub u32);Expand description
DFSDM channel y analog watchdog and short-circuit detector register.
Tuple Fields
0: u32Implementations
impl Awscdr
impl Awscdr
pub const fn scdt(&self) -> u8
pub const fn scdt(&self) -> u8
Short-circuit detector threshold for channel y These bits are written by software to define the threshold counter for the short-circuit detector. If this value is reached, then a short-circuit detector event occurs on a given channel.
pub const fn set_scdt(&mut self, val: u8)
pub const fn set_scdt(&mut self, val: u8)
Short-circuit detector threshold for channel y These bits are written by software to define the threshold counter for the short-circuit detector. If this value is reached, then a short-circuit detector event occurs on a given channel.
pub const fn bkscd(&self) -> u8
pub const fn bkscd(&self) -> u8
Break signal assignment for short-circuit detector on channel y BKSCD[i] = 0: Break i signal not assigned to short-circuit detector on channel y BKSCD[i] = 1: Break i signal assigned to short-circuit detector on channel y.
pub const fn set_bkscd(&mut self, val: u8)
pub const fn set_bkscd(&mut self, val: u8)
Break signal assignment for short-circuit detector on channel y BKSCD[i] = 0: Break i signal not assigned to short-circuit detector on channel y BKSCD[i] = 1: Break i signal assigned to short-circuit detector on channel y.
pub const fn awfosr(&self) -> u8
pub const fn awfosr(&self) -> u8
Analog watchdog filter oversampling ratio (decimation rate) on channel y also the decimation ratio of the analog data rate. This bit can be modified only when CHEN=0 (in DFSDM_CHyCFGR1 register). Note: If AWFOSR = 0 then the filter has no effect (filter bypass). 0 - 31: Defines the length of the Sinc type filter in the range 1 - 32 (AWFOSR + 1).
pub const fn set_awfosr(&mut self, val: u8)
pub const fn set_awfosr(&mut self, val: u8)
Analog watchdog filter oversampling ratio (decimation rate) on channel y also the decimation ratio of the analog data rate. This bit can be modified only when CHEN=0 (in DFSDM_CHyCFGR1 register). Note: If AWFOSR = 0 then the filter has no effect (filter bypass). 0 - 31: Defines the length of the Sinc type filter in the range 1 - 32 (AWFOSR + 1).
pub const fn awford(&self) -> u8
pub const fn awford(&self) -> u8
Analog watchdog Sinc filter order on channel y. This bit can be modified only when CHEN=0 (in DFSDM_CHyCFGR1 register).
pub const fn set_awford(&mut self, val: u8)
pub const fn set_awford(&mut self, val: u8)
Analog watchdog Sinc filter order on channel y. This bit can be modified only when CHEN=0 (in DFSDM_CHyCFGR1 register).