Struct Cfgr2
#[repr(transparent)]pub struct Cfgr2(pub u32);Expand description
DFSDM channel y configuration register.
Tuple Fields
0: u32Implementations
impl Cfgr2
impl Cfgr2
pub const fn dtrbs(&self) -> u8
pub const fn dtrbs(&self) -> u8
Data right bit-shift for channel y will be performed to have final results. Bit-shift is performed before offset correction. The data shift is rounding the result to nearest integer value. The sign of shifted result is maintained (to have valid 24-bit signed format of result data). This value can be modified only when CHEN=0 (in DFSDM_CHyCFGR1 register). 0-31: Defines the shift of the data result coming from the integrator - how many bit shifts to the right.
pub const fn set_dtrbs(&mut self, val: u8)
pub const fn set_dtrbs(&mut self, val: u8)
Data right bit-shift for channel y will be performed to have final results. Bit-shift is performed before offset correction. The data shift is rounding the result to nearest integer value. The sign of shifted result is maintained (to have valid 24-bit signed format of result data). This value can be modified only when CHEN=0 (in DFSDM_CHyCFGR1 register). 0-31: Defines the shift of the data result coming from the integrator - how many bit shifts to the right.
pub const fn offset(&self) -> u32
pub const fn offset(&self) -> u32
24-bit calibration offset for channel y For channel y, OFFSET is applied to the results of each conversion from this channel. This value is set by software.
pub const fn set_offset(&mut self, val: u32)
pub const fn set_offset(&mut self, val: u32)
24-bit calibration offset for channel y For channel y, OFFSET is applied to the results of each conversion from this channel. This value is set by software.