stm32-metapac

Crates

git

Versions

stm32f412ze

Flavors

Wdatr

Struct Wdatr 

#[repr(transparent)]
pub struct Wdatr(pub u32);
DFSDM channel y watchdog filter data register.

Tuple Fields

0: u32

Implementations



impl Wdatr

pub const fn wdata(&self) -> u16

Input channel y watchdog data Data converted by the analog watchdog filter for input channel y. This data is continuously converted (no trigger) for this channel, with a limited resolution (OSR=1..32/sinc order = 1..3).

pub const fn set_wdata(&mut self, val: u16)

Input channel y watchdog data Data converted by the analog watchdog filter for input channel y. This data is continuously converted (no trigger) for this channel, with a limited resolution (OSR=1..32/sinc order = 1..3).